@@ -1,6 +1,10 @@
 """AskUI Vision Agent"""
 
-__version__ = "0.14.0"
+__version__ = "0.16.0"
+
+import os
+
+os.environ["FASTMCP_EXPERIMENTAL_ENABLE_NEW_OPENAPI_PARSER"] = "true"
 
 from .agent import VisionAgent
 from .locators import Locator
