@@ -1,9 +1,8 @@
 from typing import Literal
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 
-from askui.chat.api.models import AssistantId
-from askui.utils.api_utils import Resource
+from askui.chat.api.models import AssistantId, WorkspaceId, WorkspaceResource
 from askui.utils.datetime_utils import UnixDatetime, now
 from askui.utils.id_utils import generate_time_ordered_id
 from askui.utils.not_given import NOT_GIVEN, BaseModelWithNotGiven, NotGiven
@@ -15,6 +14,8 @@ class AssistantBase(BaseModel):
     name: str | None = None
     description: str | None = None
     avatar: str | None = None
+    tools: list[str] = Field(default_factory=list)
+    system: str | None = None
 
 
 class AssistantCreateParams(AssistantBase):
@@ -27,9 +28,11 @@ class AssistantModifyParams(BaseModelWithNotGiven):
     name: str | NotGiven = NOT_GIVEN
     description: str | NotGiven = NOT_GIVEN
     avatar: str | NotGiven = NOT_GIVEN
+    tools: list[str] | NotGiven = NOT_GIVEN
+    system: str | NotGiven = NOT_GIVEN
 
 
-class Assistant(AssistantBase, Resource):
+class Assistant(AssistantBase, WorkspaceResource):
     """An assistant that can be used in a thread."""
 
     id: AssistantId
@@ -37,10 +40,13 @@ class Assistant(AssistantBase, Resource):
     created_at: UnixDatetime
 
     @classmethod
-    def create(cls, params: AssistantCreateParams) -> "Assistant":
+    def create(
+        cls, workspace_id: WorkspaceId, params: AssistantCreateParams
+    ) -> "Assistant":
         return cls(
             id=generate_time_ordered_id("asst"),
             created_at=now(),
+            workspace_id=workspace_id,
             **params.model_dump(),
         )
 
