@@ -21,20 +21,22 @@ from askui.models.models import (
     ModelComposition,
     ModelName,
     ModelRegistry,
-    Point,
+    PointList,
 )
 from askui.models.shared.agent import Agent
 from askui.models.shared.agent_message_param import MessageParam
 from askui.models.shared.agent_on_message_cb import OnMessageCb
 from askui.models.shared.facade import ModelFacade
 from askui.models.shared.settings import ActSettings
-from askui.models.shared.tools import Tool
+from askui.models.shared.tools import ToolCollection
 from askui.models.types.response_schemas import ResponseSchema
 from askui.reporting import NULL_REPORTER, CompositeReporter, Reporter
 from askui.utils.image_utils import ImageSource
+from askui.utils.source_utils import Source
 
 from ..logger import logger
 from .askui.inference_api import AskUiInferenceApi
+from .ui_tars_ep.ui_tars_api import UiTarsApiHandler, UiTarsApiHandlerSettings
 
 
 def initialize_default_model_registry(  # noqa: C901
@@ -103,6 +105,20 @@ def initialize_default_model_registry(  # noqa: C901
             locator_serializer=vlm_locator_serializer(),
         )
 
+    @functools.cache
+    def tars_handler() -> UiTarsApiHandler:
+        try:
+            settings = UiTarsApiHandlerSettings()
+            locator_serializer = VlmLocatorSerializer()
+            return UiTarsApiHandler(
+                reporter=reporter,
+                settings=settings,
+                locator_serializer=locator_serializer,
+            )
+        except Exception as e:  # noqa: BLE001
+            error_msg = f"Failed to initialize TARS model: {e}"
+            raise ValueError(error_msg)  # noqa: B904
+
     return {
         ModelName.ANTHROPIC__CLAUDE__3_5__SONNET__20241022: anthropic_facade,
         ModelName.ASKUI: askui_facade,
@@ -118,6 +134,7 @@ def initialize_default_model_registry(  # noqa: C901
         ModelName.HF__SPACES__QWEN__QWEN2_VL_7B_INSTRUCT: hf_spaces_handler,
         ModelName.HF__SPACES__OS_COPILOT__OS_ATLAS_BASE_7B: hf_spaces_handler,
         ModelName.HF__SPACES__SHOWUI__2B: hf_spaces_handler,
+        ModelName.TARS: tars_handler,
     }
 
 
@@ -167,7 +184,7 @@ class ModelRouter:
         messages: list[MessageParam],
         model_choice: str,
         on_message: OnMessageCb | None = None,
-        tools: list[Tool] | None = None,
+        tools: ToolCollection | None = None,
         settings: ActSettings | None = None,
     ) -> None:
         m = self._get_model(model_choice, "act")
@@ -183,20 +200,20 @@ class ModelRouter:
     def get(
         self,
         query: str,
-        image: ImageSource,
+        source: Source,
         model_choice: str,
         response_schema: Type[ResponseSchema] | None = None,
     ) -> ResponseSchema | str:
         m = self._get_model(model_choice, "get")
         logger.debug(f'Routing "get" to model "{model_choice}"')
-        return m.get(query, image, response_schema, model_choice)
+        return m.get(query, source, response_schema, model_choice)
 
     def locate(
         self,
         screenshot: ImageSource,
         locator: str | Locator,
         model_choice: ModelComposition | str,
-    ) -> Point:
+    ) -> PointList:
         _model_choice = (
             ModelName.ASKUI
             if isinstance(model_choice, ModelComposition)
