@@ -1,12 +1,15 @@
+import json
+import types
 from abc import ABC, abstractmethod
-from typing import Any, Literal, cast
+from datetime import timedelta
+from typing import Any, Literal, Protocol, Type
 
+import jsonref
+import mcp
 from anthropic.types.beta import BetaToolParam, BetaToolUnionParam
 from anthropic.types.beta.beta_tool_param import InputSchema
 from asyncer import syncify
-from fastmcp import Client
-from fastmcp.client.client import CallToolResult
-from fastmcp.client.transports import ClientTransportT
+from fastmcp.client.client import CallToolResult, ProgressHandler
 from mcp import Tool as McpTool
 from PIL import Image
 from pydantic import BaseModel, Field
@@ -59,7 +62,7 @@ def _convert_to_content(
                         ImageBlockParam(
                             source=Base64ImageSourceParam(
                                 media_type=media_type,
-                                data=result.data,
+                                data=block.data,  # type: ignore[union-attr]
                             )
                         )
                     )
@@ -128,6 +131,44 @@ class AgentException(Exception):
         super().__init__(self.message)
 
 
+class McpClientProtocol(Protocol):
+    async def list_tools(self) -> list[mcp.types.Tool]: ...
+
+    async def call_tool(
+        self,
+        name: str,
+        arguments: dict[str, Any] | None = None,
+        timeout: timedelta | float | None = None,  # noqa: ASYNC109
+        progress_handler: ProgressHandler | None = None,
+        raise_on_error: bool = True,
+    ) -> CallToolResult: ...
+
+    async def __aenter__(self) -> Self: ...
+
+    async def __aexit__(
+        self,
+        exc_type: Type[BaseException] | None,
+        exc_value: BaseException | None,
+        traceback: types.TracebackType | None,
+    ) -> None: ...
+
+
+def _replace_refs(tool_name: str, input_schema: InputSchema) -> InputSchema:
+    try:
+        return jsonref.replace_refs(  # type: ignore[no-any-return]
+            input_schema,
+            lazy_load=False,
+            proxies=False,
+        )
+    except Exception as e:  # noqa: BLE001
+        logger.exception(
+            f"Failed to replace refs for tool {tool_name}: {json.dumps(input_schema)}. "
+            "Falling back to original "
+            f"input schema which may be invalid or not be supported by the model: {e}"
+        )
+        return input_schema
+
+
 class ToolCollection:
     """A collection of tools.
 
@@ -146,18 +187,32 @@ class ToolCollection:
     Args:
         tools (list[Tool] | None, optional): The tools to add to the collection.
             Defaults to `None`.
-        mcp_client (Client[ClientTransportT] | None, optional): The client to use for
+        mcp_client (McpClientProtocol | None, optional): The client to use for
             the tools. Defaults to `None`.
     """
 
     def __init__(
         self,
         tools: list[Tool] | None = None,
-        mcp_client: Client[ClientTransportT] | None = None,
+        mcp_client: McpClientProtocol | None = None,
+        include: set[str] | None = None,
     ) -> None:
         _tools = tools or []
         self._tool_map = {tool.to_params()["name"]: tool for tool in _tools}
         self._mcp_client = mcp_client
+        self._include = include
+
+    def retrieve_tool_beta_flags(self) -> list[str]:
+        result: set[str] = set()
+        for tool in self._get_mcp_tools().values():
+            beta_flags = (tool.meta or {}).get("betas", [])
+            if not isinstance(beta_flags, list):
+                continue
+            for beta_flag in beta_flags:
+                if not isinstance(beta_flag, str):
+                    continue
+                result.add(beta_flag)
+        return list(result)
 
     def to_params(self) -> list[BetaToolUnionParam]:
         tool_map = {
@@ -167,23 +222,28 @@ class ToolCollection:
                 for tool_name, tool in self._tool_map.items()
             },
         }
-        return list(tool_map.values())
+        filtered_tool_map = {
+            tool_name: tool
+            for tool_name, tool in tool_map.items()
+            if self._include is None or tool_name in self._include
+        }
+        return list(filtered_tool_map.values())
 
     def _get_mcp_tool_params(self) -> dict[str, BetaToolUnionParam]:
         if not self._mcp_client:
             return {}
         mcp_tools = self._get_mcp_tools()
-        return {
-            tool_name: cast(
-                "BetaToolUnionParam",
-                BetaToolParam(
-                    name=tool_name,
-                    description=tool.description or "",
-                    input_schema=tool.inputSchema,
-                ),
+        result: dict[str, BetaToolUnionParam] = {}
+        for tool_name, tool in mcp_tools.items():
+            if params := (tool.meta or {}).get("params"):
+                # validation missing
+                result[tool_name] = params
+            result[tool_name] = BetaToolParam(
+                name=tool_name,
+                description=tool.description or "",
+                input_schema=_replace_refs(tool_name, tool.inputSchema),
             )
-            for tool_name, tool in mcp_tools.items()
-        }
+        return result
 
     def append_tool(self, *tools: Tool) -> "Self":
         """Append a tool to the collection."""
@@ -220,9 +280,7 @@ class ToolCollection:
             tool_use_id=tool_use_block_param.id,
         )
 
-    async def _list_mcp_tools(
-        self, mcp_client: Client[ClientTransportT]
-    ) -> list[McpTool]:
+    async def _list_mcp_tools(self, mcp_client: McpClientProtocol) -> list[McpTool]:
         async with mcp_client:
             return await mcp_client.list_tools()
 
@@ -262,7 +320,7 @@ class ToolCollection:
 
     async def _call_mcp_tool(
         self,
-        mcp_client: Client[ClientTransportT],
+        mcp_client: McpClientProtocol,
         tool_use_block_param: ToolUseBlockParam,
     ) -> ToolCallResult:
         async with mcp_client:
