@@ -28,6 +28,42 @@ def path_fixtures_screenshots(path_fixtures: pathlib.Path) -> pathlib.Path:
     return path_fixtures / "screenshots"
 
 
+@pytest.fixture
+def path_fixtures_pdf(path_fixtures: pathlib.Path) -> pathlib.Path:
+    """Fixture providing the path to the pdf directory."""
+    return path_fixtures / "pdf"
+
+
+@pytest.fixture
+def path_fixtures_dummy_pdf(path_fixtures_pdf: pathlib.Path) -> pathlib.Path:
+    """Fixture providing the path to the dummy pdf."""
+    return path_fixtures_pdf / "dummy.pdf"
+
+
+@pytest.fixture
+def path_fixtures_excel(path_fixtures: pathlib.Path) -> pathlib.Path:
+    """Fixture providing the path to the excel directory."""
+    return path_fixtures / "excel"
+
+
+@pytest.fixture
+def path_fixtures_dummy_excel(path_fixtures_excel: pathlib.Path) -> pathlib.Path:
+    """Fixture providing the path to the dummy excel."""
+    return path_fixtures_excel / "dummy.xlsx"
+
+
+@pytest.fixture
+def path_fixtures_docs(path_fixtures: pathlib.Path) -> pathlib.Path:
+    """Fixture providing the path to the docs directory."""
+    return path_fixtures / "docs"
+
+
+@pytest.fixture
+def path_fixtures_dummy_doc(path_fixtures_docs: pathlib.Path) -> pathlib.Path:
+    """Fixture providing the path to the dummy doc."""
+    return path_fixtures_docs / "dummy.docx"
+
+
 @pytest.fixture
 def github_login_screenshot(path_fixtures_screenshots: pathlib.Path) -> Image.Image:
     """Fixture providing the GitHub login screenshot."""
