@@ -7,12 +7,21 @@ from unittest.mock import Mock
 from fastapi import status
 from fastapi.testclient import TestClient
 
+from askui.chat.api.assistants.service import AssistantService
 from askui.chat.api.runs.models import Run
 from askui.chat.api.runs.service import RunService
 from askui.chat.api.threads.models import Thread
 from askui.chat.api.threads.service import ThreadService
 
 
+def create_mock_mcp_client_manager_manager() -> Mock:
+    """Create a properly configured mock MCP config service."""
+    mock_service = Mock()
+    # Configure mock to return proper data structure
+    mock_service.get_mcp_client_manager.return_value = None
+    return mock_service
+
+
 class TestRunsAPI:
     """Test suite for the runs API endpoints."""
 
@@ -44,10 +53,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -110,10 +125,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -177,10 +198,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -227,10 +254,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -287,10 +320,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -341,10 +380,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -384,10 +429,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -439,10 +490,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -485,10 +542,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -534,10 +597,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -596,10 +665,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -640,10 +715,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -721,10 +802,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -801,10 +888,16 @@ class TestRunsAPI:
             return ThreadService(workspace_path, mock_message_service, mock_run_service)
 
         def override_runs_service() -> RunService:
+            mock_assistant_service = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
             mock_message_service = Mock()
             mock_message_translator = Mock()
             return RunService(
-                workspace_path, mock_message_service, mock_message_translator
+                base_dir=workspace_path,
+                assistant_service=mock_assistant_service,
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
             )
 
         app.dependency_overrides[get_thread_service] = override_thread_service
@@ -836,3 +929,179 @@ class TestRunsAPI:
         )
 
         assert response.status_code == status.HTTP_404_NOT_FOUND
+
+    def test_create_run_with_custom_assistant(
+        self, test_headers: dict[str, str]
+    ) -> None:
+        """Test creating a run with a custom assistant."""
+        temp_dir = tempfile.mkdtemp()
+        workspace_path = Path(temp_dir)
+        threads_dir = workspace_path / "threads"
+        threads_dir.mkdir(parents=True, exist_ok=True)
+        assistants_dir = workspace_path / "assistants"
+        assistants_dir.mkdir(parents=True, exist_ok=True)
+
+        # Create a mock thread
+        mock_thread = Thread(
+            id="thread_test123",
+            object="thread",
+            created_at=1234567890,
+            name="Test Thread",
+        )
+        (threads_dir / "thread_test123.json").write_text(mock_thread.model_dump_json())
+
+        # Create a mock custom assistant
+        from askui.chat.api.assistants.models import Assistant
+
+        mock_assistant = Assistant(
+            id="asst_custom123",
+            object="assistant",
+            created_at=1234567890,
+            name="Custom Assistant",
+            tools=["tool1", "tool2"],
+            system="You are a custom assistant.",
+        )
+        (assistants_dir / "asst_custom123.json").write_text(
+            mock_assistant.model_dump_json()
+        )
+
+        from askui.chat.api.app import app
+        from askui.chat.api.assistants.dependencies import get_assistant_service
+        from askui.chat.api.runs.dependencies import get_runs_service
+        from askui.chat.api.threads.dependencies import get_thread_service
+
+        def override_thread_service() -> ThreadService:
+            from askui.chat.api.threads.service import ThreadService
+
+            mock_message_service = Mock()
+            mock_run_service = Mock()
+            return ThreadService(workspace_path, mock_message_service, mock_run_service)
+
+        def override_runs_service() -> RunService:
+            mock_message_service = Mock()
+            mock_message_translator = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
+            from askui.chat.api.assistants.service import AssistantService
+
+            return RunService(
+                base_dir=workspace_path,
+                assistant_service=AssistantService(workspace_path),
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
+            )
+
+        def override_assistant_service() -> AssistantService:
+            from askui.chat.api.assistants.service import AssistantService
+
+            return AssistantService(workspace_path)
+
+        app.dependency_overrides[get_thread_service] = override_thread_service
+        app.dependency_overrides[get_runs_service] = override_runs_service
+        app.dependency_overrides[get_assistant_service] = override_assistant_service
+
+        try:
+            with TestClient(app) as client:
+                response = client.post(
+                    "/v1/threads/thread_test123/runs",
+                    headers=test_headers,
+                    json={"assistant_id": "asst_custom123"},
+                )
+
+                assert response.status_code == status.HTTP_201_CREATED
+                data = response.json()
+                assert data["assistant_id"] == "asst_custom123"
+                assert data["thread_id"] == "thread_test123"
+                assert data["status"] == "queued"
+                assert "id" in data
+                assert "created_at" in data
+        finally:
+            app.dependency_overrides.clear()
+
+    def test_create_run_with_custom_assistant_empty_tools(
+        self, test_headers: dict[str, str]
+    ) -> None:
+        """Test creating a run with a custom assistant that has empty tools."""
+        temp_dir = tempfile.mkdtemp()
+        workspace_path = Path(temp_dir)
+        threads_dir = workspace_path / "threads"
+        threads_dir.mkdir(parents=True, exist_ok=True)
+        assistants_dir = workspace_path / "assistants"
+        assistants_dir.mkdir(parents=True, exist_ok=True)
+
+        # Create a mock thread
+        mock_thread = Thread(
+            id="thread_test123",
+            object="thread",
+            created_at=1234567890,
+            name="Test Thread",
+        )
+        (threads_dir / "thread_test123.json").write_text(mock_thread.model_dump_json())
+
+        # Create a mock custom assistant with empty tools
+        from askui.chat.api.assistants.models import Assistant
+
+        mock_assistant = Assistant(
+            id="asst_customempty123",
+            object="assistant",
+            created_at=1234567890,
+            name="Empty Tools Assistant",
+            tools=[],
+            system="You are a assistant with no tools.",
+        )
+        (assistants_dir / "asst_customempty123.json").write_text(
+            mock_assistant.model_dump_json()
+        )
+
+        from askui.chat.api.app import app
+        from askui.chat.api.assistants.dependencies import get_assistant_service
+        from askui.chat.api.runs.dependencies import get_runs_service
+        from askui.chat.api.threads.dependencies import get_thread_service
+
+        def override_thread_service() -> ThreadService:
+            from askui.chat.api.threads.service import ThreadService
+
+            mock_message_service = Mock()
+            mock_run_service = Mock()
+            return ThreadService(workspace_path, mock_message_service, mock_run_service)
+
+        def override_runs_service() -> RunService:
+            mock_message_service = Mock()
+            mock_message_translator = Mock()
+            mock_mcp_client_manager_manager = create_mock_mcp_client_manager_manager()
+            from askui.chat.api.assistants.service import AssistantService
+
+            return RunService(
+                base_dir=workspace_path,
+                assistant_service=AssistantService(workspace_path),
+                mcp_client_manager_manager=mock_mcp_client_manager_manager,
+                message_service=mock_message_service,
+                message_translator=mock_message_translator,
+            )
+
+        def override_assistant_service() -> AssistantService:
+            from askui.chat.api.assistants.service import AssistantService
+
+            return AssistantService(workspace_path)
+
+        app.dependency_overrides[get_thread_service] = override_thread_service
+        app.dependency_overrides[get_runs_service] = override_runs_service
+        app.dependency_overrides[get_assistant_service] = override_assistant_service
+
+        try:
+            with TestClient(app) as client:
+                response = client.post(
+                    "/v1/threads/thread_test123/runs",
+                    headers=test_headers,
+                    json={"assistant_id": "asst_customempty123"},
+                )
+
+                assert response.status_code == status.HTTP_201_CREATED
+                data = response.json()
+                assert data["assistant_id"] == "asst_customempty123"
+                assert data["thread_id"] == "thread_test123"
+                assert data["status"] == "queued"
+                assert "id" in data
+                assert "created_at" in data
+        finally:
+            app.dependency_overrides.clear()
